#!/usr/bin/perl

# nets_from_ips.pl, distributed as part of Snortsnarf v072700.1
# Author: James Hoagland, Silicon Defense (hoagland@SiliconDefense.com)
# copyright (c) 2000 by Silicon Defense (http://www.silicondefense.com/)
# Released under GNU General Public License, see the COPYING file included
# with the distribution or http://www.silicondefense.com/snortsnarf/ for
# details.

# nets_from_ips.pl is a Pipeline module used to extract the network portion
#   (of a given size) of IP addresses in a field.  The distinct results are
#   sorted and stored in a field, separated by commas.  The module can
#   accept a broad array of formats for input strings.  The netmask size
#   can be in the range [1,32] but only 8, 16, 24, and 32 produce correct
#   results at present.
# pipeline args: IP address input field, output field
# side effect: output loc get set

# Please send complaints, kudos, and especially improvements and bugfixes to
# hoagland@SiliconDefense.com.  As described in GNU General Public License, no
# warranty is expressed for this program.

sub process {
	use Net::hostent;
	require "sisr_utils.pl";
	my ($input)= shift;
	@_ == 2 || (&reporterr("nets_from_ips.pl takes 1 arguments (names/addresses,output loc), but got:".join(' ',@_),0) && return 0);
	my($names,$outloc)= @_;
	($names)= &arg_to_val($names);

	my %res=();
	my $out;
	foreach (split(/[^\w\.\-]+/,$names)) {
		$out= gethost($_);
		$res{$out}++;
	}
	$out= join(',',keys %res);
	
	&write_out_to_arg($input,$outloc,$out);
};

\&process;

# $Id: nets_from_ips.pl,v 1.2 2000/06/14 18:37:14 jim Exp $
